==> optimizely-oui-46.7.0.tgz: package/module/js/components/DragAndDrop/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) { return; } var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import PropTypes from 'prop-types';
import React from 'react';
import { useCallback } from 'react';
import { DragDropContext, Droppable } from 'react-beautiful-dnd';
import DraggableItem from './DraggableItem';

var DragAndDrop = function DragAndDrop(_ref) {
  var idForDroppableRegion = _ref.idForDroppableRegion,
      items = _ref.items,
      onBeforeCapture = _ref.onBeforeCapture,
      onDragEnd = _ref.onDragEnd,
      renderItem = _ref.renderItem,
      useCustomDragHandle = _ref.useCustomDragHandle;
  var updateOrderOfItems = useCallback(function (result) {
    var destination = result.destination,
        source = result.source;

    if (!destination) {
      return;
    }

    if (destination.droppableId === source.droppableId && destination.index === source.index) {
      return;
    }

    var currentItems = items;
    var newOrderOfItems = Array.from(currentItems);

    var _newOrderOfItems$spli = newOrderOfItems.splice(source.index, 1),
        _newOrderOfItems$spli2 = _slicedToArray(_newOrderOfItems$spli, 1),
        removedItem = _newOrderOfItems$spli2[0];

    newOrderOfItems.splice(destination.index, 0, removedItem);
    onDragEnd(newOrderOfItems);
  }, [onDragEnd]);
  return React.createElement(DragDropContext, {
    onBeforeCapture: onBeforeCapture,
    onDragEnd: updateOrderOfItems
  }, React.createElement(Droppable, {
    droppableId: idForDroppableRegion
  }, function (provided) {
    return React.createElement("div", _extends({
      className: "oui-sortable",
      ref: provided.innerRef
    }, provided.droppableProps), React.createElement("ul", null, items.map(function (item, index) {
      return React.createElement(DraggableItem, {
        key: item.id,
        item: item,
        id: item.id,
        index: index,
        renderFunc: renderItem,
        useCustomDragHandle: useCustomDragHandle
      });
    })), provided.placeholder);
  }));
};

DragAndDrop.propTypes = {
  /**
   * ID used for this Droppable region
   */
  idForDroppableRegion: PropTypes.string.isRequired,

  /**
   * Array of items to render as DraggableItems
   */
  items: PropTypes.arrayOf(PropTypes.shape({
    id: PropTypes.number
  })).isRequired,

  /**
   * Function to perform an action before item dimensions are captured
   */
  onBeforeCapture: PropTypes.func,

  /**
   * Function to perform an action after dragging has finished
   */
  onDragEnd: PropTypes.func,

  /**
   * Function used to render each draggable item
   */
  renderItem: PropTypes.func.isRequired,

  /**
   * Whether or not items themselves will make use of the drag handle
   */
  useCustomDragHandle: PropTypes.bool
};
DragAndDrop.defaultProps = {
  onBeforeCapture: function onBeforeCapture() {},
  onDragEnd: function onDragEnd() {},
  useCustomDragHandle: false
};
export default DragAndDrop;

==> optimizely-oui-48.14.0.tgz: package/module/js/components/DragAndDrop/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) { return; } var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import PropTypes from "prop-types";
import React, { useCallback } from "react";
import { DragDropContext, Droppable } from "react-beautiful-dnd";
import classNames from "classnames";
import DraggableItem from "./DraggableItem";

var DragAndDrop = function DragAndDrop(_ref) {
  var className = _ref.className,
      idForDroppableRegion = _ref.idForDroppableRegion,
      items = _ref.items,
      onBeforeCapture = _ref.onBeforeCapture,
      onDragEnd = _ref.onDragEnd,
      renderItem = _ref.renderItem,
      useCustomDragHandle = _ref.useCustomDragHandle,
      props = _objectWithoutProperties(_ref, ["className", "idForDroppableRegion", "items", "onBeforeCapture", "onDragEnd", "renderItem", "useCustomDragHandle"]);

  var updateOrderOfItems = useCallback(function (result) {
    var destination = result.destination,
        source = result.source;

    if (!destination) {
      return;
    }

    if (destination.droppableId === source.droppableId && destination.index === source.index) {
      return;
    }

    var currentItems = items;
    var newOrderOfItems = Array.from(currentItems);

    var _newOrderOfItems$spli = newOrderOfItems.splice(source.index, 1),
        _newOrderOfItems$spli2 = _slicedToArray(_newOrderOfItems$spli, 1),
        removedItem = _newOrderOfItems$spli2[0];

    newOrderOfItems.splice(destination.index, 0, removedItem);
    onDragEnd(newOrderOfItems);
  }, [onDragEnd]);
  return React.createElement(DragDropContext, {
    onBeforeCapture: onBeforeCapture,
    onDragEnd: updateOrderOfItems
  }, React.createElement(Droppable, {
    droppableId: idForDroppableRegion
  }, function (provided) {
    return React.createElement("div", _extends({
      className: classNames("oui-sortable", className),
      ref: provided.innerRef
    }, provided.droppableProps, props), React.createElement("ul", null, items.map(function (item, index) {
      return React.createElement(DraggableItem, {
        key: item.id,
        item: item,
        id: item.id,
        index: index,
        renderFunc: renderItem,
        useCustomDragHandle: useCustomDragHandle
      });
    })), provided.placeholder);
  }));
};

DragAndDrop.propTypes = {
  /** CSS class names. */
  className: PropTypes.string,

  /**
   * ID used for this Droppable region
   */
  idForDroppableRegion: PropTypes.string.isRequired,

  /**
   * Array of items to render as DraggableItems
   */
  items: PropTypes.arrayOf(PropTypes.shape({
    id: PropTypes.number
  })).isRequired,

  /**
   * Function to perform an action before item dimensions are captured
   */
  onBeforeCapture: PropTypes.func,

  /**
   * Function to perform an action after dragging has finished
   */
  onDragEnd: PropTypes.func,

  /**
   * Function used to render each draggable item
   */
  renderItem: PropTypes.func.isRequired,

  /**
   * Whether or not items themselves will make use of the drag handle
   */
  useCustomDragHandle: PropTypes.bool
};
DragAndDrop.defaultProps = {
  onBeforeCapture: function onBeforeCapture() {
    return null;
  },
  onDragEnd: function onDragEnd() {
    return null;
  },
  useCustomDragHandle: false
};
export default DragAndDrop;
